#!/usr/bin/perl

###########################################################################
# Example.pl
#
# This script combines the calculation of CAI and the estimation of an expected value (eCAI).
# It calculates a normalized value defined as the quotient between the CAI of a gene and its 
# expected value.
# The expected CAI value could be meaningless if the composition of the query sequences are very heterogeneous.
#
# The source code of the CAIcal_ECAI local version must be in the same folder
###########################################################################


###########################################################################
#PARAMETERS
###########################################################################
$file = "input.txt";    #The "input" file must contain a set of DNA sequences in FASTA format
$e = "cai_and_expected"; # cai/expected/cai_and_expected
$h = "reference.txt"; #The "reference" file must contain the codon usage of the reference set
$g = "11";  #Genetic code
$c = "95";
$p = "99";
$n = "1000";
$l = "300";
$m = "poisson";
$s = "n";
$result = "RESULT.txt"; #Output file

############################################################################
#SCRIPT
############################################################################

open (result, ">$result");
print result "NAME\tCAI\teCAI\tNORMALIZED\tSIGNIFICANCE ($c %)\n";
$cont = 0;

system "perl CAIcal_ECAI_v1.1.pl -e $e -f $file -h $h -g $g -c $c -p $p -o1 out1 -o2 out2 -o3 out3 -n $n -l $l -m $m -s $s";

#ECAI
open (IN3, "<out3");
while (<IN3>) {
	if (/^Upper/) {
		$ecai = /(\d+\.\d+)/;
		$ecai = $1;
	}
}
close IN3;

# CAI
open (IN1, "<out1");
$res=<IN1>;
while (<IN1>) {
	chomp $_;
	($name,$cai) = split (/\t/, $_);
	$cai=~s/ //g;
		
	# Normalized
	$normalized = $cai/$ecai;

	# Significance
	if ($normalized > 1) {
		$sig = "*";
	}else {
		$sig = "ns";
	}
	
print  result  "$name\t$cai\t$ecai\t$normalized\t$sig\n";
}
close IN1;
close result;






